curved_nav_fixed_center library
A beautiful curved bottom navigation bar with fixed center curve and smooth animations.
This library provides a customizable curved navigation bar where the curve stays fixed at the center position, offering a better user experience compared to libraries with moving curves.
Classes
- A beautiful curved bottom navigation bar with fixed center curve.
- Represents a single navigation item in the curved navigation bar.
- FixedCurvedStyle
- Defines the visual styling for the curved navigation bar.